Module clock

Module clock 

Clock traits and implementations.

Structs

MonotonicClock
A clock implementation that provides monotonically increasing time.
NanoMonotonicClock
A clock implementation that provides nanosecond-precision monotonic time.
SystemClock
A clock implementation that uses the system’s wall clock time.
Zoned
A wrapper that adds timezone support to any clock.

Traits

Clock
A trait representing a clock that provides UTC time.
ControllableClock
A trait representing a clock that can be controlled.
NanoClock
A trait representing a clock with nanosecond precision.
ZonedClock
A trait representing a clock with timezone support.