#[non_exhaustive]pub enum TimerFailurePoint {
Registration,
Completion,
}Available on crate feature
test-util only.Expand description
Selects which stage of a Timer operation reports the configured failure.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Registration
Timer::at rejects the deadline without returning a future.
Completion
Timer::at succeeds and its returned future reports the failure.