Module timer

Module timer 

Timer capabilities for asynchronous deadline notification.

Structs

ManualTimer
An asynchronous timer driven by one manual monotonic time domain.
StdTimer
A real-time asynchronous timer backed by std::time::Instant.
TokioTimertokio
An asynchronous timer backed by one Tokio runtime time driver.

Traits

Timer
Creates asynchronous notifications in one monotonic clock domain.

Type Aliases

TimerFuture
An owned future that becomes ready when a timer reaches its deadline.