Module clock

Module clock 

Clock traits and implementations.

Structs

MockClock
A controllable clock implementation for testing.
MockNanoClock
A nanosecond-precision controllable clock implementation for testing.
MonotonicClock
A clock implementation that provides monotonically increasing time.
NanoMonotonicClock
A clock implementation that provides nanosecond-precision monotonic time.
SystemClock
A clock implementation that uses the system’s wall clock time.
Zoned
A wrapper that adds timezone support to any clock.

Enums

MockClockProgression
Controls whether a mock clock stays frozen or progresses with monotonic time.

Traits

Clock
A trait representing a clock that provides UTC time.
ControllableClock
A trait representing a clock that can be controlled.
NanoClock
A trait representing a clock with nanosecond precision.
ZonedClock
A trait representing a clock with timezone support.