Clock traits and implementations.
Structs
- Mock
Clock - A controllable clock implementation for testing.
- Mock
Nano Clock - A nanosecond-precision controllable clock implementation for testing.
- Monotonic
Clock - A clock implementation that provides monotonically increasing time.
- Nano
Monotonic Clock - A clock implementation that provides nanosecond-precision monotonic time.
- System
Clock - A clock implementation that uses the system’s wall clock time.
- Zoned
- A wrapper that adds timezone support to any clock.
Enums
- Mock
Clock Progression - Controls whether a mock clock stays frozen or progresses with monotonic time.
Traits
- Clock
- A trait representing a clock that provides UTC time.
- Controllable
Clock - A trait representing a clock that can be controlled.
- Nano
Clock - A trait representing a clock with nanosecond precision.
- Zoned
Clock - A trait representing a clock with timezone support.