pub struct ManualWaiterFuture { /* private fields */ }Expand description
A future that completes when a manual clock has enough registered waiters.
This is a deterministic synchronization primitive for tests. Its observer is registered when the future is created, before its first poll. Dropping an incomplete future unregisters the observer from the clock.