Timer capabilities for asynchronous deadline notification.
Structs
- Manual
Timer - An asynchronous timer driven by one manual monotonic time domain.
- StdTimer
- A real-time asynchronous timer backed by
std::time::Instant. - Tokio
Timer tokio - An asynchronous timer backed by one Tokio runtime time driver.
Traits
- Timer
- Creates asynchronous notifications in one monotonic clock domain.
Type Aliases
- Timer
Future - An owned future that becomes ready when a timer reaches its deadline.